import { BeforeInsert, BeforeUpdate, Column, PrimaryGeneratedColumn } from 'typeorm';

export abstract class CommonEntity {
  @Column({
    type: 'double precision',
    default: 1,
  })
  created_at: number;

  @Column({
    type: 'double precision',
    default: 1,
  })
  updated_at: number;

  @PrimaryGeneratedColumn('identity', {
    type: 'bigint',
  })
  id: string;

  @BeforeInsert()
  protected insertDates() {
    const unixTimestamp = performance.timeOrigin + performance.now();

    this.created_at = unixTimestamp;
    this.updated_at = unixTimestamp;
  }

  @BeforeUpdate()
  protected updateDates() {
    this.updated_at = performance.timeOrigin + performance.now();
  }
}
