import { Column, Entity } from 'typeorm';
import { BOOLEAN, IMedia } from '../enums/_common.enum';
import { CONVERSATION_STATUS, CONVERSATION_TYPE } from '../enums/conversation.enum';
import { CommonEntity } from './_common.entity';

@Entity('conversation')
export class ConversationEntity extends CommonEntity {
  @Column({
    type: 'varchar',
    nullable: true,
  })
  name: string;

  @Column({
    type: 'json',
    nullable: true,
  })
  avatar: IMedia;

  @Column({
    type: 'smallint',
  })
  type: CONVERSATION_TYPE;

  @Column({
    type: 'bigint',
    array: true,
  })
  members: string[];

  @Column({
    type: 'json',
    nullable: true,
  })
  background: IMedia;

  @Column({
    type: 'smallint',
  })
  no_of_member: number;

  @Column({
    type: 'smallint',
    default: 0,
  })
  no_of_pinned: number;

  @Column({
    type: 'int',
    default: 0,
  })
  no_of_image: number;

  @Column({
    type: 'int',
    default: 0,
  })
  no_of_video: number;

  @Column({
    type: 'int',
    default: 0,
  })
  no_of_file: number;

  @Column({
    type: 'int',
    default: 0,
  })
  no_of_link: number;

  @Column({
    type: 'int',
    default: 0,
  })
  no_of_audio: number;

  @Column({
    type: 'varchar',
    nullable: true,
  })
  link_join: string;

  @Column({
    type: 'smallint',
    default: BOOLEAN.TRUE,
  })
  is_update_profile: BOOLEAN;

  @Column({
    type: 'smallint',
    default: BOOLEAN.TRUE,
  })
  is_user_remove: number;

  @Column({
    type: 'smallint',
    default: BOOLEAN.TRUE,
  })
  is_create_reminder: BOOLEAN;

  @Column({
    type: 'smallint',
    default: BOOLEAN.TRUE,
  })
  is_create_vote: BOOLEAN;

  @Column({
    type: 'smallint',
    default: BOOLEAN.FALSE,
  })
  is_confirm_new_member: BOOLEAN;

  @Column({
    type: 'smallint',
    default: BOOLEAN.TRUE,
  })
  is_highlight_message_admin: BOOLEAN;

  @Column({
    type: 'smallint',
    default: BOOLEAN.TRUE,
  })
  is_view_old_message_with_new_member: BOOLEAN;

  @Column({
    type: 'smallint',
    default: BOOLEAN.TRUE,
  })
  is_join_with_link: BOOLEAN;

  @Column({
    type: 'smallint',
    default: BOOLEAN.TRUE,
  })
  is_send_message: BOOLEAN;

  @Column({
    type: 'bigint',
    nullable: true,
  })
  last_message_id: string;

  @Column({
    type: 'double precision',
    nullable: true,
  })
  last_activity: number;

  @Column({
    type: 'smallint',
    default: CONVERSATION_STATUS.ACTIVE,
  })
  status: CONVERSATION_STATUS;
}
