import { Column, Entity } from 'typeorm';
import { BOOLEAN, IMedia, ITag, IThumbnail } from '../enums/_common.enum';
import { POST_AUTO_POST_TYPE, POST_STATUS, POST_TARGET_STATUS, POST_TYPES, POST_VIEW } from '../enums/post.enum';
import { CommonEntity } from './_common.entity';

@Entity('post')
export class PostEntity extends CommonEntity {
  @Column({
    type: 'bigint',
  })
  user_id: string;

  @Column({
    type: 'int',
  })
  is_review: BOOLEAN;

  @Column({
    type: 'int',
    default: POST_AUTO_POST_TYPE.NOT_AUTO,
  })
  auto_post_type: POST_AUTO_POST_TYPE;

  @Column({
    type: 'bigint',
    nullable: true,
  })
  branch_id: string;

  @Column({
    type: 'bigint',
    nullable: true,
  })
  brand_id: string;

  @Column({
    type: 'bigint',
    nullable: true,
  })
  restaurant_id: string;

  @Column({
    type: 'smallint',
  })
  post_type: POST_TYPES;

  @Column({
    type: 'bigint',
    nullable: true,
  })
  target_id: number;

  /**
   * Tiêu đề bài viết
   */
  @Column({
    type: 'varchar',
    nullable: true,
  })
  title: string;

  /**
   * Nội dung bài viết
   */
  @Column({
    type: 'text',
    nullable: true,
  })
  content: string;

  @Column({
    type: 'json',
    nullable: true,
  })
  medias: IMedia;

  @Column({
    type: 'json',
    nullable: true,
  })
  thumbnail: IThumbnail;

  @Column({
    type: 'real',
    nullable: true,
  })
  average_rating: number;

  @Column({
    type: 'real',
    nullable: true,
  })
  food_rating: number;

  @Column({
    type: 'real',
    nullable: true,
  })
  price_rating: number;

  @Column({
    type: 'real',
    nullable: true,
  })
  spatial_rating: number;

  @Column({
    type: 'real',
    nullable: true,
  })
  hygiene_rating: number;

  @Column({
    type: 'real',
    nullable: true,
  })
  service_rating: number;

  @Column({
    type: 'json',
    nullable: true,
  })
  tag: ITag;

  @Column({
    type: 'int',
    default: 0,
  })
  no_of_comment: number;

  @Column({
    type: 'int',
    default: 0,
  })
  no_of_love: number;

  @Column({
    type: 'int',
    default: 0,
  })
  no_of_wow: number;

  @Column({
    type: 'int',
    default: 0,
  })
  no_of_sad: number;

  @Column({
    type: 'int',
    default: 0,
  })
  no_of_angry: number;

  @Column({
    type: 'int',
    default: 0,
    nullable: true,
  })
  no_of_value: number;

  @Column({
    type: 'int',
    default: 0,
  })
  no_of_nothing: number;

  @Column({
    type: 'int',
    default: 0,
  })
  value: number;

  @Column({
    type: 'int',
    default: 0,
  })
  action_level: number;

  @Column({
    type: 'int',
    default: 0,
  })
  no_of_share: number;

  @Column({
    type: 'smallint',
    default: BOOLEAN.TRUE,
  })
  is_share: BOOLEAN;

  @Column({
    type: 'bigint',
    nullable: true,
  })
  post_share_id: string;

  @Column({
    type: 'smallint',
  })
  view: POST_VIEW;

  @Column({
    type: 'smallint',
    default: BOOLEAN.FALSE,
  })
  is_detect: BOOLEAN;

  // /**
  //  *Bài viết có phải là bài đăng avatar không
  //  */
  // @Column({
  //   type: 'smallint',
  //   default: 0,
  // })
  // is_avatar_post: number;

  //Tình trạng bài viết 0-waiting, 1-accepted, 2-revoke
  @Column({
    type: 'smallint',
    default: POST_TARGET_STATUS.CONFIRM,
  })
  target_status: POST_TARGET_STATUS;

  @Column({
    type: 'bigint',
    default: [],
    array: true,
  })
  card_tag: string[];

  @Column({
    type: 'smallint',
    default: POST_STATUS.ACTIVE,
  })
  status: POST_STATUS;
}
