import { Column, Entity } from 'typeorm';
import { BOOLEAN } from '../enums/_common.enum';
import { USER_STATUS } from '../enums/user.enum';
import { CommonEntity } from './_common.entity';

@Entity('user')
export class UserEntity extends CommonEntity {
  @Column({
    type: 'varchar',
  })
  avatar: string;

  @Column({
    type: 'varchar',
  })
  full_name: string;

  @Column({
    type: 'varchar',
    nullable: true,
  })
  nick_name: string;

  @Column({
    type: 'smallint',
    default: 0,
  })
  identification: number;

  @Column({
    type: 'varchar',
    nullable: true,
  })
  address: string;

  @Column({
    type: 'real',
    nullable: true,
  })
  lat: number;

  @Column({
    type: 'real',
    nullable: true,
  })
  lng: number;

  @Column({
    type: 'bigint',
    nullable: true,
  })
  city_id: string;

  @Column({
    type: 'bigint',
    nullable: true,
  })
  district_id: string;

  @Column({
    type: 'bigint',
    nullable: true,
  })
  ward_id: string;

  @Column({
    type: 'bigint',
    nullable: true,
  })
  country_id: number;

  @Column({
    type: 'int',
    default: 0,
  })
  no_of_alo_point: number;

  @Column({
    type: 'int',
    default: 0,
  })
  no_of_follow: number;

  @Column({
    type: 'int',
    default: 0,
  })
  view: number;

  @Column({
    type: 'text',
    nullable: true,
  })
  cover: string;

  @Column({
    type: 'varchar',
  })
  phone: string;

  @Column({
    type: 'smallint',
    default: 0,
  })
  gender: number;

  @Column({
    type: 'varchar',
    nullable: true,
  })
  birthday: string;

  @Column({
    type: 'varchar',
    nullable: true,
  })
  first_name: string;

  @Column({
    type: 'varchar',
    nullable: true,
  })
  last_name: string;

  @Column({
    type: 'smallint',
    default: 0,
  })
  no_of_friend: number;

  @Column({
    type: 'text',
    nullable: true,
  })
  description: string;

  @Column({
    type: 'varchar',
    nullable: true,
  })
  website: string;

  @Column({
    type: 'varchar',
    nullable: true,
  })
  email: string;

  @Column({
    type: 'int',
    array: true,
    default: [],
  })
  user_interests: number[];

  @Column({
    type: 'smallint',
    default: BOOLEAN.TRUE,
  })
  is_notify: BOOLEAN;

  @Column({
    type: 'smallint',
    default: BOOLEAN.FALSE,
  })
  is_dark_mode: BOOLEAN;

  @Column({
    type: 'smallint',
    default: BOOLEAN.TRUE,
  })
  view_about: BOOLEAN;

  @Column({
    type: 'smallint',
    default: BOOLEAN.TRUE,
  })
  view_life_event: BOOLEAN;

  @Column({
    type: 'smallint',
    default: BOOLEAN.TRUE,
  })
  view_friend: BOOLEAN;

  @Column({
    type: 'smallint',
    default: BOOLEAN.TRUE,
  })
  view_media: BOOLEAN;

  @Column({
    type: 'smallint',
    default: BOOLEAN.TRUE,
  })
  is_request_friend: BOOLEAN;

  @Column({
    type: 'smallint',
    default: BOOLEAN.TRUE,
  })
  is_display_name: BOOLEAN;

  @Column({
    type: 'smallint',
    default: BOOLEAN.TRUE,
  })
  is_enable_gender: BOOLEAN;

  @Column({
    type: 'smallint',
    default: BOOLEAN.TRUE,
  })
  is_enable_birthday: BOOLEAN;

  @Column({
    type: 'smallint',
    default: BOOLEAN.TRUE,
  })
  is_enable_phone: BOOLEAN;

  @Column({
    type: 'smallint',
    default: BOOLEAN.TRUE,
  })
  is_enable_email: BOOLEAN;

  @Column({
    type: 'smallint',
    default: BOOLEAN.TRUE,
  })
  is_enable_address: BOOLEAN;

  @Column({
    type: 'smallint',
    default: BOOLEAN.TRUE,
  })
  is_enable_city: BOOLEAN;

  @Column({
    type: 'smallint',
    default: BOOLEAN.TRUE,
  })
  is_enable_district: BOOLEAN;

  @Column({
    type: 'smallint',
    default: BOOLEAN.TRUE,
  })
  is_enable_ward: BOOLEAN;

  @Column({
    type: 'timestamp',
    nullable: true,
  })
  time_seen_notify: Date;

  @Column({
    type: 'timestamp',
    nullable: true,
  })
  last_connect: Date;

  @Column({
    type: 'bigint',
    nullable: true,
  })
  restaurant_id: string;

  @Column({
    type: 'smallint',
    default: USER_STATUS.ACTIVE,
  })
  status: USER_STATUS;
}
